@@ -906,7 +906,7 @@ def _regularize_files_inner(
                         *[match.group(0)[1:-1].split(",") for match in matches]
                     ):
                         tmp = expanded
-                        for c, m in list(zip(combination, matches))[::-1]:
+                        for c, m in list(zip(combination, matches, strict=True))[::-1]:
                             tmp = tmp[: m.span()[0]] + c + tmp[m.span()[1] :]
                         results.append(tmp)
 
